# Table of Contents

- [sample-queries](<./sample-queries.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Sample GraphQL Queries](<./Sample-GraphQL-Queries.md>)
  - [Was this page helpful?](<./Sample-GraphQL-Queries/Was-this-page-helpful.md>)
